# SDIF Tools

SDIF reader provides a set of classes built from the Swimming Data Interchange Format V3. The specification document was pulled from the US Masters Swimming website and is provided in this repository for reference.
